Learn R Programming

AgreementInterval (version 0.1.1)

aiAdj: aiAdj

Description

Function aiAdj calculates bias-adjusted average interval from ai object

Usage

aiAdj(object, x)

Arguments

object

ai object from ai function

x

A numeric value or a vector of numeric values to calculate bias-adjusted average interval for

Value

bias-adjusted and total-adjusted average interval for each value in x

Details

Function aiAdj uses proportional bias per x unit, Liao's average interval, Liao's average interval adjusted for fixed bias to calculate bias-adjusted and total-adjusted average interval.

References

Jason J. Z. Liao, Quantifying an Agreement Study, Int. J. Biostat. 2015; 11(1): 125-133

Examples

Run this code
# NOT RUN {
ans <- ai(x=IPIA$Tomography, y=IPIA$Urography)
aiAdj(object=ans, x=1)
aiAdj(object=ans, x=c(1, 2))
# }

Run the code above in your browser using DataLab